=======================
Reference documentation
=======================

This is the class and function reference of fmralign. Please refer to
the :ref:`full user guide <user_guide>` for further details, as the class and
function raw specifications may not be enough to give full guidelines on their
uses.


.. _pairwise_alignment_ref:

:mod:`fmralign.alignment.pairwise_alignment`: Pairwise Alignment
================================================================

.. automodule:: fmralign.alignment.pairwise_alignment
  :no-members:
  :no-inherited-members:

**Classes**:

.. currentmodule:: fmralign.alignment.pairwise_alignment

.. autosummary::
  :toctree: generated/
  :template: class.rst

   PairwiseAlignment

.. _group_alignment_ref:

:mod:`fmralign.alignment.group_alignment`: Group Alignment
==========================================================

.. automodule:: fmralign.alignment.group_alignment
 :no-members:
 :no-inherited-members:

**Classes**:

.. currentmodule:: fmralign.alignment.group_alignment

.. autosummary::
 :toctree: generated/
 :template: class.rst

  GroupAlignment

.. _alignment_methods_ref:
